++++++++++++
Introduction
++++++++++++

=====
About
=====

Spot is a graphical tool created to assist with planning and 
conducting astronomical observations.  It can display the telescope 
targets and telescope position on a polar sky plot, and plot the 
visibilty of targets. SPOT can also be setup to look up catalog 
images and overlay instrument fields of view. 

Spot is written and maintained by software engineers at the
Subaru Telescope, National Astronomical Observatory of Japan and other
maintainers.  The code is released as open-source under a BSD license
and maintained at https://github.com/naojsoft/spot.

========
Features
========

Here are few of the things SPOT can do:

- You can select a site and date/time when you plan to observe (it's also
  easy to add your own custom site).
- It can show you an astronomical almanac of information about a particular
  date (sunrise, sunset, moonrise, moonset, twilights, etc).
- It can load lists of targets and plot them on a polar plot for their
  position in the sky at the current time or any given time.
- It can show you the various targets' visibility as a plot of altitude
  vs. time.
- It can overlay fisheye-type sky camera images on the polar plot so that
  you can monitor for cloud coverage.
- With the right customization it can show you where your telescope target
  is, the current telescope position and the slew that it will take to get
  there on the polar plot.
- It can look up catalog images from various sources for a given target
  and show instrument detector overlays on top, with adjustable position
  angle.
